@@ -479,15 +479,18 @@ sub reset_token_verify {
 
     # check token and expiry against DB and compare checksum
 
-    if (   $self->reset_token eq $token
-        && ( !$self->reset_expires || DateTime->now <= $self->reset_expires )
-        && $self->reset_token_checksum eq $checksum )
-    {
-        return 1;
-    }
-    else {
-        return 0;
+    # The following should be combined in a single 'if' statement but sadly
+    # we then end up with Devel::Cover being unable to test the condition
+    # correctly so instead we break it out into ugly code. At least it
+    # means we know our tests are covering all condition. :(
+    if ( $self->reset_token eq $token ) {
+        if ( !$self->reset_expires || DateTime->now <= $self->reset_expires ) {
+            if ( $self->reset_token_checksum eq $checksum ) {
+                return 1;
+            }
+        }
     }
+    return 0;
 }
 
 =head2 new
@@ -535,11 +538,13 @@ sub insert {
     my $user_role = $self->result_source->schema->resultset('Role')
       ->find( { name => $role_name } );
 
+    # uncoverable branch false
     if ( $user_role ) {
         $self->create_related( 'user_roles', { roles_id => $user_role->id } );
     }
     else {
         # we should never get here
+        # uncoverable statement
         $self->throw_exception(
             "Role with name 'user' must exist when creating a new user");
     }
@@ -584,13 +589,14 @@ sub check_username {
 
 =head2 blog_posts
 
-Returns resultset of messages that are blog posts (Message->type eq 'blog_post')
+Returns resultset of messages that are blog posts
 
 =cut
 
 sub blog_posts {
     my $self = shift;
-    return $self->messages->search( { type => 'blog_post' } );
+    return $self->messages->search( { 'message_type.name' => 'blog_post' },
+        { join => 'message_type' } );
 }
 
 =head2 name
@@ -606,13 +612,14 @@ sub name {
 
 =head2 reviews
 
-Returns resultset of messages that are reviews (referenced by ProductReview class).
+Returns resultset of messages that are reviews.
 
 =cut
 
 sub reviews {
     my $self = shift;
-    return $self->messages->search( {}, { join => 'product_review' } );
+    return $self->messages->search( { 'message_type.name' => 'product_review' },
+        { join => 'message_type' } );
 }
 
 1;
