@@ -19,7 +19,7 @@ FK on L<Interchange6::Schema::Result::User/users_id>.
 =cut
 
 column users_id =>
-  { data_type => "integer", is_foreign_key => 1 };
+  { data_type => "integer" };
 
 =head2 roles_id
 
@@ -28,7 +28,7 @@ FK on L<Interchange6::Schema::Result::Role/roles_id>.
 =cut
 
 column roles_id =>
-  { data_type => "integer", is_foreign_key => 1 };
+  { data_type => "integer" };
 
 =head1 PRIMARY KEY
 
