@@ -7,10 +7,7 @@ Interchange6::Test::Role::Fixtures
 
 =cut
 
-use Interchange6::Schema::Populate::CountryLocale;
-use Interchange6::Schema::Populate::MessageType;
-use Interchange6::Schema::Populate::StateLocale;
-use Interchange6::Schema::Populate::Zone;
+use Interchange6::Schema::Populate;
 use Sub::Quote qw/quote_sub/;
 use DateTime;
 
@@ -24,6 +21,30 @@ my @accessors = qw(orders addresses shipment_rates taxes zones states
   countries navigation price_modifiers roles inventory media products
   attributes users uri_redirects message_types shipment_carriers);
 
+# we also need a package global mapping of accessor to result class
+
+our %accessor2class = (
+    addresses         => "Address",
+    attributes        => "Attribute",
+    countries         => "Country",
+    #currencies        => "Currency",
+    inventory         => "Inventory",
+    media             => "Media",
+    message_types     => "MessageType",
+    navigation        => "Navigation",
+    orders            => "Order",
+    price_modifiers   => "PriceModifier",
+    products          => "Product",
+    roles             => "Role",
+    shipment_carriers => "ShipmentCarrier",
+    shipment_rates    => "ShipmentRate",
+    states            => "State",
+    taxes             => "Tax",
+    uri_redirects     => "UriRedirect",
+    users             => "User",
+    zones             => "Zone",
+);
+
 # Create all of the accessors and clearers. Builders should be defined later.
 
 foreach my $accessor (@accessors) {
@@ -39,11 +60,12 @@ foreach my $accessor (@accessors) {
 
     my $cref = q{
         my $self = shift;
-        $self->$accessor->delete_all;
+        $self->ic6s_schema->resultset($class)->delete;
         my $_clear_accessor = "_clear_$accessor";
         $self->$_clear_accessor;
     };
-    quote_sub "main::clear_$accessor", $cref, { '$accessor' => \$accessor };
+    quote_sub "main::clear_$accessor", $cref,
+      { '$accessor' => \$accessor, '$class' => \$accessor2class{$accessor} };
 }
 
 # clearing products is not so simple...
@@ -82,6 +104,7 @@ sub clear_products {
         $product->delete;
     }
     $self->_clear_products;
+    $self->clear_price_modifiers;
 }
 
 =head1 ATTRIBUTES
@@ -179,9 +202,10 @@ Populated via L<Interchange6::Schema::Populate::CountryLocale>.
 sub _build_countries {
     my $self    = shift;
     my $rset    = $self->ic6s_schema->resultset('Country');
+
     if ( $rset->count == 0 ) {
-        my $pop = Interchange6::Schema::Populate::CountryLocale->new->records;
-        $rset->populate($pop) or die "Failed to populate Country";
+        Interchange6::Schema::Populate->new( schema => $self->ic6s_schema )
+          ->populate_countries;
     }
     return $rset;
 }
@@ -195,8 +219,8 @@ sub _build_roles {
     my $rset = $self->ic6s_schema->resultset("Role");
 
     if ( $rset->count == 0 ) {
-        my $pop = Interchange6::Schema::Populate::Role->new->records;
-        $rset->populate($pop) or die "Failed to populate Role";
+        Interchange6::Schema::Populate->new( schema => $self->ic6s_schema )
+          ->populate_roles;
     }
 
     # Add a few additional roles
@@ -447,6 +471,7 @@ sub _build_products {
 
     # we must have attributes and message_types (for reviews)
     $self->attributes unless $self->has_attributes;
+    #$self->currencies unless $self->has_currencies;
     $self->message_types unless $self->has_message_types;
 
     my @products = (
@@ -1399,9 +1424,8 @@ sub _build_message_types {
     my $rset = $self->ic6s_schema->resultset('MessageType');
 
     if ( $rset->count == 0 ) {
-        my $pop = Interchange6::Schema::Populate::MessageType->new->records;
-        scalar $rset->populate($pop)
-            or die "Failed to populate MessageType";
+        Interchange6::Schema::Populate->new( schema => $self->ic6s_schema )
+          ->populate_message_types;
     }
     return $rset;
 }
@@ -1600,8 +1624,8 @@ sub _build_states {
     $self->countries unless $self->has_countries;
 
     if ( $rset->count == 0 ) {
-        my $pop = Interchange6::Schema::Populate::StateLocale->new->records;
-        scalar $rset->populate($pop) or die "Failed to populate State";
+        Interchange6::Schema::Populate->new( schema => $self->ic6s_schema )
+          ->populate_states;
     }
     return $rset;
 }
@@ -1720,12 +1744,12 @@ sub _build_uri_redirects {
 
 =head2 users
 
-    [qw( username email password )],
-    [ 'customer1', 'customer1@example.com', 'c1passwd' ],
-    [ 'customer2', 'customer2@example.com', 'c1passwd' ],
-    [ 'customer3', 'customer3@example.com', 'c1passwd' ],
-    [ 'admin1',    'admin1@example.com',    'a1passwd' ],
-    [ 'admin2',    'admin2@example.com',    'a2passwd' ],
+    [qw( username email password nickname )],
+    [ 'customer1', 'customer1@example.com', 'c1passwd', 'Cust1' ],
+    [ 'customer2', 'customer2@example.com', 'c1passwd', 'Cust2' ],
+    [ 'customer3', 'customer3@example.com', 'c1passwd', 'Cust3' ],
+    [ 'admin1',    'admin1@example.com',    'a1passwd', 'Deity1' ],
+    [ 'admin2',    'admin2@example.com',    'a2passwd', 'Deity2' ],
 
 =cut
 
@@ -1738,24 +1762,32 @@ sub _build_users {
 
     scalar $rset->populate(
         [
-            [qw( username email password first_name last_name)],
+            [qw( username email password first_name last_name nickname)],
             [
                 'customer1', 'customer1@example.com',
                 'c1passwd',  "Customer",
-                "One"
+                "One",       "Cust1",
             ],
             [
                 'customer2', 'customer2@example.com',
                 'c1passwd',  "Customer",
-                "Two"
+                "Two",       "Cust2",
             ],
             [
                 'customer3', 'customer3@example.com',
                 'c1passwd',  "Customer",
-                "Three"
+                "Three",     "Cust3",
+            ],
+            [
+                'admin1',   'admin1@example.com',
+                'a1passwd', "Admin",
+                "One",      "Deity1"
+            ],
+            [
+                'admin2',   'admin2@example.com',
+                'a2passwd', "Admin",
+                "Two",      "Deity2"
             ],
-            [ 'admin1', 'admin1@example.com', 'a1passwd', "Admin", "One" ],
-            [ 'admin2', 'admin2@example.com', 'a2passwd', "Admin", "Two" ],
         ]
     );
 
@@ -1777,22 +1809,8 @@ sub _build_zones {
     my $rset = $self->ic6s_schema->resultset('Zone');
 
     if ( $rset->count == 0 ) {
-        # we need to pass min value of states_id to ::Populate::Zone
-        # also kicks in states and countries builders if not already set
-
-        my $min_states_id = $self->states->search(
-            {},
-            {
-                select => [ { min => 'states_id' } ],
-                as     => ['min_id'],
-            }
-        )->first->get_column('min_id');
-
-        my $pop =
-        Interchange6::Schema::Populate::Zone->new(
-            states_id_initial_value => $min_states_id )->records;
-
-        scalar $rset->populate($pop) or die "Failed to populate Zone";
+        Interchange6::Schema::Populate->new( schema => $self->ic6s_schema )
+          ->populate_zones;
     }
     return $rset;
 }
