@@ -1,6 +1,7 @@
 package Test::Navigation;
 use utf8;
 
+use Test::Deep;
 use Test::Exception;
 use Test::Roo::Role;
 
@@ -13,7 +14,7 @@ test 'navigation tests' => sub {
     # prereqs
     $self->navigation unless $self->has_navigation;
 
-    my ( $nav, $navlist, $nav_product, $result );
+    my ( $nav, $navlist, $nav_product, $result, @results );
 
     my $product = $self->products->find('os28077');
 
@@ -106,6 +107,11 @@ test 'navigation tests' => sub {
     cmp_ok( $nav->siblings_with_self->count, "==", 9,
         "9 siblings with self" );
 
+    lives_ok { @results = $nav->siblings_with_self }
+    "get array of nav siblings";
+
+    cmp_ok( scalar @results, "==", 9, "9 siblings with self (list context)" );
+
     # generate_uri
 
     my %data = (
@@ -254,6 +260,20 @@ test 'navigation tests' => sub {
 
     ok( !defined $nav->uri, "uri is undef" );
 
+    lives_ok {
+        $product = $self->products->create(
+            {
+                name        => "product with no nav",
+                sku         => "productnonav",
+                price       => 1,
+                description => ""
+            }
+          )
+    }
+    "create product with no nav";
+
+    cmp_deeply ( [$product->path], [], "product->path is epmty list" );
+
     # cleanup
     $self->clear_navigation;
 };
